@@ -1,6 +1,6 @@
 // This file is part of BOINC.
 // https://boinc.berkeley.edu
-// Copyright (C) 2018 University of California
+// Copyright (C) 2019 University of California
 //
 // BOINC is free software; you can redistribute it and/or modify it
 // under the terms of the GNU Lesser General Public License
@@ -83,7 +83,8 @@ using std::vector;
 using std::sort;
 
 int OLD_RESULT::parse(XML_PARSER& xp) {
-    memset(this, 0, sizeof(OLD_RESULT));
+    static const OLD_RESULT x;
+    *this = x;
     while (!xp.get_tag()) {
         if (xp.match_tag("/old_result")) return 0;
         if (xp.parse_str("project_url", project_url, sizeof(project_url))) continue;
@@ -99,7 +100,8 @@ int OLD_RESULT::parse(XML_PARSER& xp) {
 }
 
 int TIME_STATS::parse(XML_PARSER& xp) {
-    memset(this, 0, sizeof(TIME_STATS));
+    static const TIME_STATS x;
+    *this = x;
     while (!xp.get_tag()) {
         if (xp.match_tag("/time_stats")) return 0;
         if (xp.parse_double("now", now)) continue;
@@ -588,7 +590,8 @@ int APP_VERSION::parse(XML_PARSER& xp) {
 }
 
 void APP_VERSION::clear() {
-    memset(this, 0, sizeof(*this));
+    static const APP_VERSION x(0);
+    *this = x;
 }
 
 WORKUNIT::WORKUNIT() {
@@ -1049,7 +1052,7 @@ void CC_STATE::clear() {
     results.clear();
     platforms.clear();
     executing_as_daemon = false;
-    host_info.clear_host_info();
+    host_info.clear();
     have_nvidia = false;
     have_ati = false;
 }
@@ -1384,6 +1387,7 @@ void ACCOUNT_IN::clear() {
     server_cookie.clear();
     ldap_auth = false;
     server_assigned_cookie = false;
+    consented_to_terms = false;
 }
 
 ACCOUNT_OUT::ACCOUNT_OUT() {
@@ -1458,7 +1462,7 @@ void CC_STATUS::clear() {
 
 /////////// END OF PARSING FUNCTIONS.  RPCS START HERE ////////////////
 
-int RPC_CLIENT::exchange_versions(VERSION_INFO& server) {
+int RPC_CLIENT::exchange_versions(string client_name, VERSION_INFO& server) {
     int retval;
     SET_LOCALE sl;
     char buf[256];
@@ -1469,15 +1473,18 @@ int RPC_CLIENT::exchange_versions(VERSION_INFO& server) {
         "   <major>%d</major>\n"
         "   <minor>%d</minor>\n"
         "   <release>%d</release>\n"
+        "   <name>%s</name>\n"
         "</exchange_versions>\n",
         BOINC_MAJOR_VERSION,
         BOINC_MINOR_VERSION,
-        BOINC_RELEASE
+        BOINC_RELEASE,
+        client_name.c_str()
     );
 
     retval = rpc.do_rpc(buf);
     if (!retval) {
-        memset(&server, 0, sizeof(server));
+        static const VERSION_INFO x;
+        server = x;
         while (rpc.fin.fgets(buf, 256)) {
             if (match_tag(buf, "</server_version>")) break;
             else if (parse_int(buf, "<major>", server.major)) continue;
@@ -1976,6 +1983,45 @@ int RPC_CLIENT::run_benchmarks() {
     return rpc.parse_reply();
 }
 
+int RPC_CLIENT::run_graphics_app(int slot, int& id, const char *operation) {
+    char buf[256];
+    SET_LOCALE sl;
+    RPC rpc(this);
+    int thePID = -1;
+    bool stop = false;
+    
+    snprintf(buf, sizeof(buf), "<run_graphics_app>\n");
+    
+    if (!strcmp(operation, "run")) {
+        snprintf(buf, sizeof(buf), "<run_graphics_app>\n<slot>%d</slot>\n<run/>\n", slot);
+    } else if (!strcmp(operation, "runfullscreen")) {
+        snprintf(buf, sizeof(buf), "<run_graphics_app>\n<slot>%d</slot>\n<runfullscreen/>\n", slot);
+    } else if (!strcmp(operation, "stop")) {
+        snprintf(buf, sizeof(buf), "<run_graphics_app>\n<graphics_pid>%d</graphics_pid>\n<stop/>\n", id);
+        stop = true;
+    } else if (!strcmp(operation, "test")) {
+        snprintf(buf, sizeof(buf), "<run_graphics_app>\n<graphics_pid>%d</graphics_pid>\n<test/>\n", id);
+    } else {
+        id = -1;
+        return -1;
+    }
+    safe_strcat(buf, "</run_graphics_app>\n");
+    int retval = rpc.do_rpc(buf);
+    if (retval) {
+        id = -1;
+    } else {
+        while (rpc.fin.fgets(buf, 256)) {
+            if (match_tag(buf, "</run_graphics_app>")) break;
+            if (parse_int(buf, "<graphics_pid>", thePID)) continue;
+        }
+        id = thePID;
+        if ((!stop) && (thePID < 0)) {
+            retval = -1;
+        }
+    }
+    return retval;
+}
+
 int RPC_CLIENT::set_proxy_settings(GR_PROXY_INFO& procinfo) {
     int retval;
     SET_LOCALE sl;
@@ -2375,12 +2421,14 @@ int RPC_CLIENT::create_account(ACCOUNT_IN& ai) {
         "   <passwd_hash>%s</passwd_hash>\n"
         "   <user_name>%s</user_name>\n"
         "   <team_name>%s</team_name>\n"
+        "   %s"
         "</create_account>\n",
         ai.url.c_str(),
         ai.email_addr.c_str(),
         passwd_hash.c_str(),
         ai.user_name.c_str(),
-        ai.team_name.c_str()
+        ai.team_name.c_str(),
+        ai.consented_to_terms ? "<consented_to_terms/>\n" : ""
     );
     buf[sizeof(buf)-1] = 0;
 
