@@ -1,6 +1,6 @@
 // This file is part of BOINC.
 // http://boinc.berkeley.edu
-// Copyright (C) 2008 University of California
+// Copyright (C) 2019 University of California
 //
 // BOINC is free software; you can redistribute it and/or modify it
 // under the terms of the GNU Lesser General Public License
@@ -87,7 +87,7 @@ static bool find_host_by_other(DB_USER& user, HOST req_host, DB_HOST& host) {
     for (unsigned int i=0; i < config.dont_search_host_for_userid.size(); i++) {
         if (user.id == config.dont_search_host_for_userid[i]) {
             return false;
-        }    
+        }
     }
 
     // Only check if all the fields are populated
@@ -1418,10 +1418,10 @@ void process_request(char* code_sign_key) {
                 if (diff < config.min_sendwork_interval) {
                     ok_to_send_work = false;
                     log_messages.printf(MSG_NORMAL,
-                        "Not sending work - last request too recent: %f\n", diff
+                        "Not sending work - last request too recent, please wait: %f\n", config.min_sendwork_interval
                     );
                     sprintf(buf,
-                        "Not sending work - last request too recent: %d sec", (int)diff
+                        "Not sending work - last request too recent, please wait: %d sec", (int)config.min_sendwork_interval
                     );
                     g_reply->insert_message(buf, "low");
 
@@ -1536,5 +1536,3 @@ void handle_request(FILE* fin, FILE* fout, char* code_sign_key) {
         unlock_sched();
     }
 }
-
-const char *BOINC_RCSID_2ac231f9de = "$Id$";
